@@ -13,7 +13,7 @@
 #
 # Note: the DB and SEARCH services to use are determined by corresponding environment
 #       variables if they are set -- otherwise, the following defaults are used:
-#       DB=postgresql, SEARCH=elasticsearch
+#       DB=postgresql, SEARCH=opensearch
 #
 # Example for using mysql instead of postgresql:
 #    DB=mysql ./run-tests.sh
@@ -52,8 +52,9 @@ if [[ ${keep_services} -eq 0 ]]; then
 fi
 
 python -m check_manifest
+python -m setup extract_messages --dry-run
 python -m sphinx.cmd.build -qnNW docs docs/_build/html
-eval "$(docker-services-cli up --db ${DB:-postgresql} --search ${SEARCH:-elasticsearch} --env)"
+eval "$(docker-services-cli up --db ${DB:-postgresql} --search ${SEARCH:-opensearch} --env)"
 # Note: expansion of pytest_args looks like below to not cause an unbound
 # variable error when 1) "nounset" and 2) the array is empty.
 python -m pytest ${pytest_args[@]+"${pytest_args[@]}"}
